aboutsummaryrefslogtreecommitdiffstats
path: root/tests/auto
diff options
context:
space:
mode:
authorJoerg Bornemann <joerg.bornemann@qt.io>2016-06-08 12:25:00 +0200
committerJoerg Bornemann <joerg.bornemann@qt.io>2016-06-08 12:25:00 +0200
commit505cadeb2a072216b904d8655f5e6e62b0f9380b (patch)
tree36a771df1107eb6c5edd3304f22fdfc3361895eb /tests/auto
parentdaf715d9cae1c297ea50587c9e40c0f24bd59a07 (diff)
parenta98416dcf9895ad6f840a0e35da10a667a8a20ae (diff)
Merge remote-tracking branch 'origin/1.5'
Conflicts: doc/reference/items/transformer.qdoc share/qbs/modules/cpp/GenericGCC.qbs Change-Id: I45560834560019b18274c373c45651eb8aadd206
Diffstat (limited to 'tests/auto')
-rw-r--r--tests/auto/api/testdata/base-properties/main.cpp2
-rw-r--r--tests/auto/api/testdata/build-properties-source/main.cpp2
-rw-r--r--tests/auto/api/testdata/change-dependent-lib/main.cpp2
-rw-r--r--tests/auto/api/testdata/change-dependent-lib/mylib.cpp2
-rw-r--r--tests/auto/api/testdata/dynamic-libs/lib1.cpp2
-rw-r--r--tests/auto/api/testdata/dynamic-libs/lib2.cpp2
-rw-r--r--tests/auto/api/testdata/dynamic-libs/lib3.cpp2
-rw-r--r--tests/auto/api/testdata/dynamic-libs/main.cpp2
-rw-r--r--tests/auto/api/testdata/export-simple/lib1.cpp2
-rw-r--r--tests/auto/api/testdata/export-simple/main.cpp2
-rw-r--r--tests/auto/api/testdata/lib-same-source/main.cpp2
-rw-r--r--tests/auto/api/testdata/link-static-lib/helper1/helper1.cpp2
-rw-r--r--tests/auto/api/testdata/link-static-lib/helper1/helper1.h2
-rw-r--r--tests/auto/api/testdata/link-static-lib/helper2/helper2.cpp2
-rw-r--r--tests/auto/api/testdata/link-static-lib/helper2/helper2.h2
-rw-r--r--tests/auto/api/testdata/link-static-lib/main.cpp2
-rw-r--r--tests/auto/api/testdata/link-static-lib/mystaticlib.cpp2
-rw-r--r--tests/auto/api/testdata/properties-blocks/main.cpp2
-rw-r--r--tests/auto/api/testdata/rc/main.cpp2
-rw-r--r--tests/auto/api/testdata/transformers/main.cpp2
-rw-r--r--tests/auto/api/testdata/uic/bla.cpp2
-rw-r--r--tests/auto/api/testdata/uic/bla.h2
-rw-r--r--tests/auto/api/testdata/uic/ui.h2
-rw-r--r--tests/auto/api/tst_api.cpp35
-rw-r--r--tests/auto/api/tst_api.h2
-rw-r--r--tests/auto/blackbox/testdata/dynamicRuleOutputs/after/numbers.l2
-rw-r--r--tests/auto/blackbox/testdata/dynamicRuleOutputs/before/flexoptionsreader.js2
-rw-r--r--tests/auto/blackbox/testdata/dynamicRuleOutputs/before/genlexer.qbs2
-rw-r--r--tests/auto/blackbox/testdata/dynamicRuleOutputs/before/numbers.l2
-rw-r--r--tests/auto/blackbox/testdata/groups-in-modules/modules/helper/diamondc.c2
-rw-r--r--tests/auto/blackbox/testdata/loadablemodule/main.cpp2
-rw-r--r--tests/auto/blackbox/testdata/missing-dependency/main.cpp5
-rw-r--r--tests/auto/blackbox/testdata/missing-dependency/missing-dependency.qbs39
-rw-r--r--tests/auto/blackbox/testdata/missing-dependency/theHeader.h.in0
-rw-r--r--tests/auto/blackbox/testdata/proper quoting/main.cpp2
-rw-r--r--tests/auto/blackbox/testdata/proper quoting/my static lib.cpp2
-rw-r--r--tests/auto/blackbox/testdata/proper quoting/some helper/some helper.cpp2
-rw-r--r--tests/auto/blackbox/testdata/proper quoting/some helper/some helper.h2
-rw-r--r--tests/auto/blackbox/testdata/qrc/bla.cpp2
-rw-r--r--tests/auto/blackbox/testdata/trackAddFile/after/main.cpp2
-rw-r--r--tests/auto/blackbox/testdata/trackAddFile/after/zort.cpp2
-rw-r--r--tests/auto/blackbox/testdata/trackAddFile/after/zort.h2
-rw-r--r--tests/auto/blackbox/testdata/trackAddFile/before/main.cpp2
-rw-r--r--tests/auto/blackbox/testdata/trackAddFile/before/narf.cpp2
-rw-r--r--tests/auto/blackbox/testdata/trackAddFile/before/narf.h2
-rw-r--r--tests/auto/blackbox/testdata/trackFileTags/after/main.cpp2
-rw-r--r--tests/auto/blackbox/testdata/trackFileTags/before/main.cpp2
-rw-r--r--tests/auto/blackbox/testdata/trackQObjChange/bla.cpp2
-rw-r--r--tests/auto/blackbox/testdata/trackQObjChange/bla_noqobject.h2
-rw-r--r--tests/auto/blackbox/testdata/trackQObjChange/bla_qobject.h2
-rw-r--r--tests/auto/blackbox/tst_blackbox.cpp17
-rw-r--r--tests/auto/blackbox/tst_blackbox.h3
-rw-r--r--tests/auto/buildgraph/tst_buildgraph.cpp2
-rw-r--r--tests/auto/cmdlineparser/tst_cmdlineparser.cpp2
-rw-r--r--tests/auto/language/tst_language.cpp2
-rw-r--r--tests/auto/tools/tst_tools.cpp2
56 files changed, 146 insertions, 53 deletions
diff --git a/tests/auto/api/testdata/base-properties/main.cpp b/tests/auto/api/testdata/base-properties/main.cpp
index 3c1bc2c58..0c735157b 100644
--- a/tests/auto/api/testdata/base-properties/main.cpp
+++ b/tests/auto/api/testdata/base-properties/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/build-properties-source/main.cpp b/tests/auto/api/testdata/build-properties-source/main.cpp
index 6020544fe..30c57e606 100644
--- a/tests/auto/api/testdata/build-properties-source/main.cpp
+++ b/tests/auto/api/testdata/build-properties-source/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/change-dependent-lib/main.cpp b/tests/auto/api/testdata/change-dependent-lib/main.cpp
index 0bf8b2823..48a9586a7 100644
--- a/tests/auto/api/testdata/change-dependent-lib/main.cpp
+++ b/tests/auto/api/testdata/change-dependent-lib/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/change-dependent-lib/mylib.cpp b/tests/auto/api/testdata/change-dependent-lib/mylib.cpp
index d74c52ce0..00ceb178e 100644
--- a/tests/auto/api/testdata/change-dependent-lib/mylib.cpp
+++ b/tests/auto/api/testdata/change-dependent-lib/mylib.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/dynamic-libs/lib1.cpp b/tests/auto/api/testdata/dynamic-libs/lib1.cpp
index 7af7cdbb1..8e920ebf1 100644
--- a/tests/auto/api/testdata/dynamic-libs/lib1.cpp
+++ b/tests/auto/api/testdata/dynamic-libs/lib1.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/dynamic-libs/lib2.cpp b/tests/auto/api/testdata/dynamic-libs/lib2.cpp
index f145e3246..b90d0ed59 100644
--- a/tests/auto/api/testdata/dynamic-libs/lib2.cpp
+++ b/tests/auto/api/testdata/dynamic-libs/lib2.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/dynamic-libs/lib3.cpp b/tests/auto/api/testdata/dynamic-libs/lib3.cpp
index e8df9d65c..726116a16 100644
--- a/tests/auto/api/testdata/dynamic-libs/lib3.cpp
+++ b/tests/auto/api/testdata/dynamic-libs/lib3.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/dynamic-libs/main.cpp b/tests/auto/api/testdata/dynamic-libs/main.cpp
index 32a310b8c..e7132d1d2 100644
--- a/tests/auto/api/testdata/dynamic-libs/main.cpp
+++ b/tests/auto/api/testdata/dynamic-libs/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/export-simple/lib1.cpp b/tests/auto/api/testdata/export-simple/lib1.cpp
index f9fddadf8..ccb3a2434 100644
--- a/tests/auto/api/testdata/export-simple/lib1.cpp
+++ b/tests/auto/api/testdata/export-simple/lib1.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/export-simple/main.cpp b/tests/auto/api/testdata/export-simple/main.cpp
index 2dd943472..718d21b63 100644
--- a/tests/auto/api/testdata/export-simple/main.cpp
+++ b/tests/auto/api/testdata/export-simple/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/lib-same-source/main.cpp b/tests/auto/api/testdata/lib-same-source/main.cpp
index 7c18babaf..996798412 100644
--- a/tests/auto/api/testdata/lib-same-source/main.cpp
+++ b/tests/auto/api/testdata/lib-same-source/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/link-static-lib/helper1/helper1.cpp b/tests/auto/api/testdata/link-static-lib/helper1/helper1.cpp
index 7d9f96285..a7287cc3d 100644
--- a/tests/auto/api/testdata/link-static-lib/helper1/helper1.cpp
+++ b/tests/auto/api/testdata/link-static-lib/helper1/helper1.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/link-static-lib/helper1/helper1.h b/tests/auto/api/testdata/link-static-lib/helper1/helper1.h
index 8a69abe68..edea18df2 100644
--- a/tests/auto/api/testdata/link-static-lib/helper1/helper1.h
+++ b/tests/auto/api/testdata/link-static-lib/helper1/helper1.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/link-static-lib/helper2/helper2.cpp b/tests/auto/api/testdata/link-static-lib/helper2/helper2.cpp
index 7bf3cb7eb..76c0db84b 100644
--- a/tests/auto/api/testdata/link-static-lib/helper2/helper2.cpp
+++ b/tests/auto/api/testdata/link-static-lib/helper2/helper2.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/link-static-lib/helper2/helper2.h b/tests/auto/api/testdata/link-static-lib/helper2/helper2.h
index 870c3ea1f..c24f061ad 100644
--- a/tests/auto/api/testdata/link-static-lib/helper2/helper2.h
+++ b/tests/auto/api/testdata/link-static-lib/helper2/helper2.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/link-static-lib/main.cpp b/tests/auto/api/testdata/link-static-lib/main.cpp
index a6c5ba211..66b1045c2 100644
--- a/tests/auto/api/testdata/link-static-lib/main.cpp
+++ b/tests/auto/api/testdata/link-static-lib/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/link-static-lib/mystaticlib.cpp b/tests/auto/api/testdata/link-static-lib/mystaticlib.cpp
index 82610656b..32e04d954 100644
--- a/tests/auto/api/testdata/link-static-lib/mystaticlib.cpp
+++ b/tests/auto/api/testdata/link-static-lib/mystaticlib.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/properties-blocks/main.cpp b/tests/auto/api/testdata/properties-blocks/main.cpp
index 18cc6563b..9f85c3689 100644
--- a/tests/auto/api/testdata/properties-blocks/main.cpp
+++ b/tests/auto/api/testdata/properties-blocks/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/rc/main.cpp b/tests/auto/api/testdata/rc/main.cpp
index 5d10372bc..60a8b7ec8 100644
--- a/tests/auto/api/testdata/rc/main.cpp
+++ b/tests/auto/api/testdata/rc/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/transformers/main.cpp b/tests/auto/api/testdata/transformers/main.cpp
index 52606e760..07a841b10 100644
--- a/tests/auto/api/testdata/transformers/main.cpp
+++ b/tests/auto/api/testdata/transformers/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/uic/bla.cpp b/tests/auto/api/testdata/uic/bla.cpp
index 062f07e11..0b55d168c 100644
--- a/tests/auto/api/testdata/uic/bla.cpp
+++ b/tests/auto/api/testdata/uic/bla.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/uic/bla.h b/tests/auto/api/testdata/uic/bla.h
index e138ab0c6..6c8cca984 100644
--- a/tests/auto/api/testdata/uic/bla.h
+++ b/tests/auto/api/testdata/uic/bla.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/testdata/uic/ui.h b/tests/auto/api/testdata/uic/ui.h
index 613d0e2fe..437e19ca9 100644
--- a/tests/auto/api/testdata/uic/ui.h
+++ b/tests/auto/api/testdata/uic/ui.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/tst_api.h b/tests/auto/api/tst_api.h
index eb88ea35a..24f8f6f18 100644
--- a/tests/auto/api/tst_api.h
+++ b/tests/auto/api/tst_api.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/dynamicRuleOutputs/after/numbers.l b/tests/auto/blackbox/testdata/dynamicRuleOutputs/after/numbers.l
index ffe194492..d0cb48770 100644
--- a/tests/auto/blackbox/testdata/dynamicRuleOutputs/after/numbers.l
+++ b/tests/auto/blackbox/testdata/dynamicRuleOutputs/after/numbers.l
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the examples of the Qt Build Suite.
+** This file is part of the examples of Qbs.
**
** You may use this file under the terms of the BSD license as follows:
**
diff --git a/tests/auto/blackbox/testdata/dynamicRuleOutputs/before/flexoptionsreader.js b/tests/auto/blackbox/testdata/dynamicRuleOutputs/before/flexoptionsreader.js
index dcb835b64..bd596fbca 100644
--- a/tests/auto/blackbox/testdata/dynamicRuleOutputs/before/flexoptionsreader.js
+++ b/tests/auto/blackbox/testdata/dynamicRuleOutputs/before/flexoptionsreader.js
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the examples of the Qt Build Suite.
+** This file is part of the examples of Qbs.
**
** You may use this file under the terms of the BSD license as follows:
**
diff --git a/tests/auto/blackbox/testdata/dynamicRuleOutputs/before/genlexer.qbs b/tests/auto/blackbox/testdata/dynamicRuleOutputs/before/genlexer.qbs
index acd587791..04820e18f 100644
--- a/tests/auto/blackbox/testdata/dynamicRuleOutputs/before/genlexer.qbs
+++ b/tests/auto/blackbox/testdata/dynamicRuleOutputs/before/genlexer.qbs
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the examples of the Qt Build Suite.
+** This file is part of the examples of Qbs.
**
** You may use this file under the terms of the BSD license as follows:
**
diff --git a/tests/auto/blackbox/testdata/dynamicRuleOutputs/before/numbers.l b/tests/auto/blackbox/testdata/dynamicRuleOutputs/before/numbers.l
index eba7065a5..26419b6c4 100644
--- a/tests/auto/blackbox/testdata/dynamicRuleOutputs/before/numbers.l
+++ b/tests/auto/blackbox/testdata/dynamicRuleOutputs/before/numbers.l
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the examples of the Qt Build Suite.
+** This file is part of the examples of Qbs.
**
** You may use this file under the terms of the BSD license as follows:
**
diff --git a/tests/auto/blackbox/testdata/groups-in-modules/modules/helper/diamondc.c b/tests/auto/blackbox/testdata/groups-in-modules/modules/helper/diamondc.c
index 31a32e5bd..fe4754d8d 100644
--- a/tests/auto/blackbox/testdata/groups-in-modules/modules/helper/diamondc.c
+++ b/tests/auto/blackbox/testdata/groups-in-modules/modules/helper/diamondc.c
@@ -3,7 +3,7 @@
** Copyright (C) 2015 Jake Petroules.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/loadablemodule/main.cpp b/tests/auto/blackbox/testdata/loadablemodule/main.cpp
index 8fbfa475c..b35e0cbbe 100644
--- a/tests/auto/blackbox/testdata/loadablemodule/main.cpp
+++ b/tests/auto/blackbox/testdata/loadablemodule/main.cpp
@@ -4,7 +4,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the examples of the Qt Build Suite.
+** This file is part of the examples of Qbs.
**
** You may use this file under the terms of the BSD license as follows:
**
diff --git a/tests/auto/blackbox/testdata/missing-dependency/main.cpp b/tests/auto/blackbox/testdata/missing-dependency/main.cpp
new file mode 100644
index 000000000..ee2bdf30e
--- /dev/null
+++ b/tests/auto/blackbox/testdata/missing-dependency/main.cpp
@@ -0,0 +1,5 @@
+#include <theHeader.h>
+
+int main()
+{
+}
diff --git a/tests/auto/blackbox/testdata/missing-dependency/missing-dependency.qbs b/tests/auto/blackbox/testdata/missing-dependency/missing-dependency.qbs
new file mode 100644
index 000000000..e3a37d415
--- /dev/null
+++ b/tests/auto/blackbox/testdata/missing-dependency/missing-dependency.qbs
@@ -0,0 +1,39 @@
+import qbs
+import qbs.TextFile
+
+Project {
+ Product {
+ name: "theDep"
+ type: ["genheader"]
+
+ // TODO: Remove in 1.6
+ Group {
+ files: ["theHeader.h.in"]
+ fileTags: ["header.in"]
+ }
+
+ Rule {
+ inputs: ["header.in"]
+ Artifact {
+ filePath: project.buildDirectory + "/theHeader.h"
+ fileTags: product.type
+ }
+ prepare: {
+ var cmd = new JavaScriptCommand();
+ cmd.silent = true;
+ cmd.sourceCode = function() {
+ var f = new TextFile(output.filePath, TextFile.WriteOnly);
+ f.close();
+ }
+ return [cmd];
+ }
+ }
+ }
+ CppApplication {
+ name: "theApp"
+ cpp.includePaths: [project.buildDirectory]
+ files: ["main.cpp"]
+ }
+}
+
+
diff --git a/tests/auto/blackbox/testdata/missing-dependency/theHeader.h.in b/tests/auto/blackbox/testdata/missing-dependency/theHeader.h.in
new file mode 100644
index 000000000..e69de29bb
--- /dev/null
+++ b/tests/auto/blackbox/testdata/missing-dependency/theHeader.h.in
diff --git a/tests/auto/blackbox/testdata/proper quoting/main.cpp b/tests/auto/blackbox/testdata/proper quoting/main.cpp
index 963bfc36a..9b76443d2 100644
--- a/tests/auto/blackbox/testdata/proper quoting/main.cpp
+++ b/tests/auto/blackbox/testdata/proper quoting/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/proper quoting/my static lib.cpp b/tests/auto/blackbox/testdata/proper quoting/my static lib.cpp
index cbc95cf65..fc7959b86 100644
--- a/tests/auto/blackbox/testdata/proper quoting/my static lib.cpp
+++ b/tests/auto/blackbox/testdata/proper quoting/my static lib.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/proper quoting/some helper/some helper.cpp b/tests/auto/blackbox/testdata/proper quoting/some helper/some helper.cpp
index 986c48afe..386fec6c1 100644
--- a/tests/auto/blackbox/testdata/proper quoting/some helper/some helper.cpp
+++ b/tests/auto/blackbox/testdata/proper quoting/some helper/some helper.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/proper quoting/some helper/some helper.h b/tests/auto/blackbox/testdata/proper quoting/some helper/some helper.h
index df9d2c050..6d4fc5ca5 100644
--- a/tests/auto/blackbox/testdata/proper quoting/some helper/some helper.h
+++ b/tests/auto/blackbox/testdata/proper quoting/some helper/some helper.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/qrc/bla.cpp b/tests/auto/blackbox/testdata/qrc/bla.cpp
index f6302ba9b..62b8757e6 100644
--- a/tests/auto/blackbox/testdata/qrc/bla.cpp
+++ b/tests/auto/blackbox/testdata/qrc/bla.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/trackAddFile/after/main.cpp b/tests/auto/blackbox/testdata/trackAddFile/after/main.cpp
index ffe384936..6520158dc 100644
--- a/tests/auto/blackbox/testdata/trackAddFile/after/main.cpp
+++ b/tests/auto/blackbox/testdata/trackAddFile/after/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/trackAddFile/after/zort.cpp b/tests/auto/blackbox/testdata/trackAddFile/after/zort.cpp
index dc0dfb410..78c682f38 100644
--- a/tests/auto/blackbox/testdata/trackAddFile/after/zort.cpp
+++ b/tests/auto/blackbox/testdata/trackAddFile/after/zort.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/trackAddFile/after/zort.h b/tests/auto/blackbox/testdata/trackAddFile/after/zort.h
index 24e61acec..bae34fdcf 100644
--- a/tests/auto/blackbox/testdata/trackAddFile/after/zort.h
+++ b/tests/auto/blackbox/testdata/trackAddFile/after/zort.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/trackAddFile/before/main.cpp b/tests/auto/blackbox/testdata/trackAddFile/before/main.cpp
index fe643f8a4..a85e0838f 100644
--- a/tests/auto/blackbox/testdata/trackAddFile/before/main.cpp
+++ b/tests/auto/blackbox/testdata/trackAddFile/before/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/trackAddFile/before/narf.cpp b/tests/auto/blackbox/testdata/trackAddFile/before/narf.cpp
index 0bc3f5659..3b450e759 100644
--- a/tests/auto/blackbox/testdata/trackAddFile/before/narf.cpp
+++ b/tests/auto/blackbox/testdata/trackAddFile/before/narf.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/trackAddFile/before/narf.h b/tests/auto/blackbox/testdata/trackAddFile/before/narf.h
index aba25c6d4..6b5ae7840 100644
--- a/tests/auto/blackbox/testdata/trackAddFile/before/narf.h
+++ b/tests/auto/blackbox/testdata/trackAddFile/before/narf.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/trackFileTags/after/main.cpp b/tests/auto/blackbox/testdata/trackFileTags/after/main.cpp
index 4bba1cee1..fbd19f778 100644
--- a/tests/auto/blackbox/testdata/trackFileTags/after/main.cpp
+++ b/tests/auto/blackbox/testdata/trackFileTags/after/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/trackFileTags/before/main.cpp b/tests/auto/blackbox/testdata/trackFileTags/before/main.cpp
index 70e2d40c8..44c5f7b71 100644
--- a/tests/auto/blackbox/testdata/trackFileTags/before/main.cpp
+++ b/tests/auto/blackbox/testdata/trackFileTags/before/main.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/trackQObjChange/bla.cpp b/tests/auto/blackbox/testdata/trackQObjChange/bla.cpp
index 9fa442b98..5d7a35ccd 100644
--- a/tests/auto/blackbox/testdata/trackQObjChange/bla.cpp
+++ b/tests/auto/blackbox/testdata/trackQObjChange/bla.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/trackQObjChange/bla_noqobject.h b/tests/auto/blackbox/testdata/trackQObjChange/bla_noqobject.h
index 0e34a21c0..df1636a39 100644
--- a/tests/auto/blackbox/testdata/trackQObjChange/bla_noqobject.h
+++ b/tests/auto/blackbox/testdata/trackQObjChange/bla_noqobject.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/testdata/trackQObjChange/bla_qobject.h b/tests/auto/blackbox/testdata/trackQObjChange/bla_qobject.h
index d391cde7b..bbb0ce24f 100644
--- a/tests/auto/blackbox/testdata/trackQObjChange/bla_qobject.h
+++ b/tests/auto/blackbox/testdata/trackQObjChange/bla_qobject.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/blackbox/tst_blackbox.h b/tests/auto/blackbox/tst_blackbox.h
index b3a089f72..18605ec9c 100644
--- a/tests/auto/blackbox/tst_blackbox.h
+++ b/tests/auto/blackbox/tst_blackbox.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
@@ -160,6 +160,7 @@ private slots:
void listPropertyOrder();
void loadableModule();
void lrelease();
+ void missingDependency();
void missingProfile();
void mixedBuildVariants();
void multipleChanges();
diff --git a/tests/auto/buildgraph/tst_buildgraph.cpp b/tests/auto/buildgraph/tst_buildgraph.cpp
index 3519b0344..9ca26aec5 100644
--- a/tests/auto/buildgraph/tst_buildgraph.cpp
+++ b/tests/auto/buildgraph/tst_buildgraph.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/cmdlineparser/tst_cmdlineparser.cpp b/tests/auto/cmdlineparser/tst_cmdlineparser.cpp
index f1f27d1e8..ed6200ad6 100644
--- a/tests/auto/cmdlineparser/tst_cmdlineparser.cpp
+++ b/tests/auto/cmdlineparser/tst_cmdlineparser.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/language/tst_language.cpp b/tests/auto/language/tst_language.cpp
index 6458d9907..3f021c8f7 100644
--- a/tests/auto/language/tst_language.cpp
+++ b/tests/auto/language/tst_language.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/tools/tst_tools.cpp b/tests/auto/tools/tst_tools.cpp
index 45a4a7ad6..9c4e90942 100644
--- a/tests/auto/tools/tst_tools.cpp
+++ b/tests/auto/tools/tst_tools.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
diff --git a/tests/auto/api/tst_api.cpp b/tests/auto/api/tst_api.cpp
index 79667ab2e..14b555b2a 100644
--- a/tests/auto/api/tst_api.cpp
+++ b/tests/auto/api/tst_api.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of the Qt Build Suite.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
@@ -251,11 +251,44 @@ void TestApi::buildGraphLocking()
QVERIFY2(!setupJob->error().hasError(), qPrintable(setupJob->error().toString()));
const qbs::Project project = setupJob->project();
Q_UNUSED(project);
+
+ // Case 1: Setting up a competing project from scratch.
setupJob.reset(qbs::Project().setupProject(setupParams, m_logSink, 0));
waitForFinished(setupJob.data());
QVERIFY(setupJob->error().hasError());
QVERIFY2(setupJob->error().toString().contains("lock"),
qPrintable(setupJob->error().toString()));
+
+ // Case 2: Setting up a non-competing project and then making it competing.
+ qbs::SetupProjectParameters setupParams2 = setupParams;
+ setupParams2.setBuildRoot(setupParams.buildRoot() + "/2");
+ setupJob.reset(qbs::Project().setupProject(setupParams2, m_logSink, 0));
+ waitForFinished(setupJob.data());
+ QVERIFY2(!setupJob->error().hasError(), qPrintable(setupJob->error().toString()));
+ const QString buildDirName = profileName() + '-' + setupParams2.buildVariant();
+ const QString lockFile = setupParams2.buildRoot() + '/' + buildDirName + '/' + buildDirName
+ + ".bg.lock";
+ QVERIFY2(QFileInfo(lockFile).isFile(), qPrintable(lockFile));
+ qbs::Project project2 = setupJob->project();
+ QVERIFY(project2.isValid());
+ setupJob.reset(project2.setupProject(setupParams, m_logSink, 0));
+ waitForFinished(setupJob.data());
+ QVERIFY(setupJob->error().hasError());
+ QVERIFY2(setupJob->error().toString().contains("lock"),
+ qPrintable(setupJob->error().toString()));
+ QVERIFY2(QFileInfo(lockFile).isFile(), qPrintable(lockFile));
+
+ // Case 3: Changing the build directory of an existing project to something con-competing.
+ qbs::SetupProjectParameters setupParams3 = setupParams2;
+ setupParams3.setBuildRoot(setupParams.buildRoot() + "/3");
+ setupJob.reset(qbs::Project().setupProject(setupParams3, m_logSink, 0));
+ waitForFinished(setupJob.data());
+ QVERIFY2(!setupJob->error().hasError(), qPrintable(setupJob->error().toString()));
+ project2 = qbs::Project();
+ QVERIFY2(!QFileInfo(lockFile).exists(), qPrintable(lockFile));
+ const QString newLockFile = setupParams3.buildRoot() + '/' + buildDirName + '/'
+ + buildDirName + ".bg.lock";
+ QVERIFY2(QFileInfo(newLockFile).isFile(), qPrintable(newLockFile));
}
void TestApi::buildProject()
@@ -3,7 +3,7 @@
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage
diff --git a/tests/auto/blackbox/tst_blackbox.cpp b/tests/auto/blackbox/tst_blackbox.cpp
index 37449f867..0c326c628 100644
--- a/tests/auto/blackbox/tst_blackbox.cpp
+++ b/tests/auto/blackbox/tst_blackbox.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of the Qt Build Suite.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
@@ -3911,6 +3911,21 @@ void TestBlackbox::lrelease()
QVERIFY(!regularFileExists(relativeProductBuildDir("lrelease-test") + "/hu.qm"));
}
+void TestBlackbox::missingDependency()
+{
+ QDir::setCurrent(testDataDir + "/missing-dependency");
+ QbsRunParameters params;
+ params.expectFailure = true;
+ params.arguments << "-p" << "theApp";
+ QVERIFY(runQbs(params) != 0);
+ QVERIFY2(!m_qbsStderr.contains("ASSERT"), m_qbsStderr.constData());
+ QCOMPARE(runQbs(QbsRunParameters(QStringList() << "-p" << "theDep")), 0);
+ params.expectFailure = false;
+ params.arguments << "-vv";
+ QCOMPARE(runQbs(params), 0);
+ QVERIFY(m_qbsStderr.contains("false positive"));
+}
+
void TestBlackbox::badInterpreter()
{
if (!HostOsInfo::isAnyUnixHost())
@@ -3,7 +3,7 @@
** Contact: http://www.qt.io/licensing
**
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
**
** Commercial License Usage